@@ -60,8 +60,6 @@ static void jabber_init(account_t *acc)
 
 	s = set_add(&acc->set, "activity_timeout", "600", set_eval_int, acc);
 
-	s = set_add(&acc->set, "oauth", "false", set_eval_oauth, acc);
-
 	s = set_add(&acc->set, "display_name", NULL, NULL, acc);
 
 	g_snprintf(str, sizeof(str), "%d", jabber_port_list[0]);
@@ -83,6 +81,12 @@ static void jabber_init(account_t *acc)
 	s = set_add(&acc->set, "server", NULL, set_eval_account, acc);
 	s->flags |= SET_NOSAVE | ACC_SET_OFFLINE_ONLY | SET_NULL_OK;
 
+	if (strcmp(acc->prpl->name, "hipchat") == 0) {
+		set_setstr(&acc->set, "server", "chat.hipchat.com");
+	} else {
+		s = set_add(&acc->set, "oauth", "false", set_eval_oauth, acc);
+	}
+
 	s = set_add(&acc->set, "ssl", "false", set_eval_bool, acc);
 	s->flags |= ACC_SET_OFFLINE_ONLY;
 
@@ -95,8 +99,17 @@ static void jabber_init(account_t *acc)
 	s = set_add(&acc->set, "user_agent", "BitlBee", NULL, acc);
 
 	s = set_add(&acc->set, "xmlconsole", "false", set_eval_bool, acc);
+
+	s = set_add(&acc->set, "mail_notifications", "false", set_eval_bool, acc);
 	s->flags |= ACC_SET_OFFLINE_ONLY;
 
+	/* changing this is rarely needed so keeping it secret */
+	s = set_add(&acc->set, "mail_notifications_limit", "5", set_eval_int, acc);
+	s->flags |= SET_HIDDEN_DEFAULT;
+
+	s = set_add(&acc->set, "mail_notifications_handle", NULL, NULL, acc);
+	s->flags |= ACC_SET_OFFLINE_ONLY | SET_NULL_OK;
+
 	acc->flags |= ACC_FLAG_AWAY_MESSAGE | ACC_FLAG_STATUS_MESSAGE |
 	              ACC_FLAG_HANDLE_DOMAINS;
 }
@@ -121,6 +134,10 @@ static void jabber_login(account_t *acc)
 
 	jd->fd = jd->r_inpa = jd->w_inpa = -1;
 
+	if (strcmp(acc->prpl->name, "hipchat") == 0) {
+		jd->flags |= JFLAG_HIPCHAT;
+	}
+
 	if (jd->server == NULL) {
 		imcb_error(ic, "Incomplete account name (format it like <username@jabberserver.name>)");
 		imc_logout(ic, FALSE);
@@ -251,6 +268,14 @@ void jabber_connect(struct im_connection *ic)
 		imcb_add_buddy(ic, JABBER_XMLCONSOLE_HANDLE, NULL);
 	}
 
+	if (set_getbool(&acc->set, "mail_notifications")) {
+		/* It's gmail specific, but it checks for server support before enabling it */
+		jd->flags |= JFLAG_GMAILNOTIFY;
+		if (set_getstr(&acc->set, "mail_notifications_handle")) {
+			imcb_add_buddy(ic, set_getstr(&acc->set, "mail_notifications_handle"), NULL);
+		}
+	}
+
 	jabber_generate_id_hash(jd);
 }
 
@@ -325,6 +350,7 @@ static void jabber_logout(struct im_connection *ic)
 	g_free(jd->oauth2_access_token);
 	g_free(jd->away_message);
 	g_free(jd->internal_jid);
+	g_free(jd->gmail_tid);
 	g_free(jd->username);
 	g_free(jd->me);
 	g_free(jd);
@@ -419,7 +445,7 @@ static void jabber_get_info(struct im_connection *ic, char *who)
 		bud = bud->next;
 	}
 
-	jabber_get_vcard(ic, bud ? bud->full_jid : who);
+	jabber_get_vcard(ic, who);
 }
 
 static void jabber_set_away(struct im_connection *ic, char *state_txt, char *message)
@@ -655,6 +681,7 @@ gboolean jabber_handle_is_self(struct im_connection *ic, const char *who)
 void jabber_initmodule()
 {
 	struct prpl *ret = g_new0(struct prpl, 1);
+	struct prpl *hipchat = NULL;
 
 	ret->name = "jabber";
 	ret->mms = 0;                        /* no limit */
@@ -685,4 +712,9 @@ void jabber_initmodule()
 	ret->buddy_action = jabber_buddy_action;
 
 	register_protocol(ret);
+
+	/* Another one for hipchat, which has completely different logins */
+	hipchat = g_memdup(ret, sizeof(struct prpl));
+	hipchat->name = "hipchat";
+	register_protocol(hipchat);
 }
