@@ -34,11 +34,12 @@
 
 static gboolean msn_ns_connected(gpointer data, gint source, b_input_condition cond);
 static gboolean msn_ns_callback(gpointer data, gint source, b_input_condition cond);
-static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_parts);
-static int msn_ns_message(struct msn_handler_data *handler, char *msg, int msglen, char **cmd, int num_parts);
 
 static void msn_ns_send_adl_start(struct im_connection *ic);
 static void msn_ns_send_adl(struct im_connection *ic);
+static void msn_ns_structured_message(struct msn_data *md, char *msg, int msglen, char **cmd);
+static void msn_ns_sdg(struct msn_data *md, char *who, char **parts, char *action);
+static void msn_ns_nfy(struct msn_data *md, char *who, char **parts, char *action, gboolean is_put);
 
 int msn_ns_write(struct im_connection *ic, int fd, const char *fmt, ...)
 {
@@ -53,15 +54,22 @@ int msn_ns_write(struct im_connection *ic, int fd, const char *fmt, ...)
 	va_end(params);
 
 	if (fd < 0) {
-		fd = md->ns->fd;
+		fd = md->fd;
 	}
 
 	if (getenv("BITLBEE_DEBUG")) {
-		fprintf(stderr, "->NS%d:%s\n", fd, out);
+		fprintf(stderr, "\x1b[91m>>>[NS%d] %s\n\x1b[97m", fd, out);
 	}
 
 	len = strlen(out);
-	st = write(fd, out, len);
+
+	if (md->is_http) {
+		st = len;
+		msn_gw_write(md->gw, out, len);
+	} else {
+		st = write(fd, out, len);
+	}
+
 	g_free(out);
 	if (st != len) {
 		imcb_error(ic, "Short write() to main server");
@@ -72,20 +80,25 @@ int msn_ns_write(struct im_connection *ic, int fd, const char *fmt, ...)
 	return 1;
 }
 
-gboolean msn_ns_connect(struct im_connection *ic, struct msn_handler_data *handler, const char *host, int port)
+gboolean msn_ns_connect(struct im_connection *ic, const char *host, int port)
 {
-	if (handler->fd >= 0) {
-		closesocket(handler->fd);
+	struct msn_data *md = ic->proto_data;
+
+	if (md->fd >= 0) {
+		closesocket(md->fd);
 	}
 
-	handler->exec_command = msn_ns_command;
-	handler->exec_message = msn_ns_message;
-	handler->data = ic;
-	handler->fd = proxy_connect(host, port, msn_ns_connected, handler);
-	if (handler->fd < 0) {
-		imcb_error(ic, "Could not connect to server");
-		imc_logout(ic, TRUE);
-		return FALSE;
+	if (md->is_http) {
+		md->gw = msn_gw_new(ic);
+		md->gw->callback = msn_ns_callback;
+		msn_ns_connected(md, -1, B_EV_IO_READ);
+	} else {
+		md->fd = proxy_connect(host, port, msn_ns_connected, md);
+		if (md->fd < 0) {
+			imcb_error(ic, "Could not connect to server");
+			imc_logout(ic, TRUE);
+			return FALSE;
+		}
 	}
 
 	return TRUE;
@@ -93,25 +106,18 @@ gboolean msn_ns_connect(struct im_connection *ic, struct msn_handler_data *handl
 
 static gboolean msn_ns_connected(gpointer data, gint source, b_input_condition cond)
 {
-	struct msn_handler_data *handler = data;
-	struct im_connection *ic = handler->data;
-	struct msn_data *md;
+	struct msn_data *md = data;
+	struct im_connection *ic = md->ic;
 
-	if (!g_slist_find(msn_connections, ic)) {
-		return FALSE;
-	}
-
-	md = ic->proto_data;
-
-	if (source == -1) {
+	if (source == -1 && !md->is_http) {
 		imcb_error(ic, "Could not connect to server");
 		imc_logout(ic, TRUE);
 		return FALSE;
 	}
 
-	g_free(handler->rxq);
-	handler->rxlen = 0;
-	handler->rxq = g_new0(char, 1);
+	g_free(md->rxq);
+	md->rxlen = 0;
+	md->rxq = g_new0(char, 1);
 
 	if (md->uuid == NULL) {
 		struct utsname name;
@@ -129,48 +135,65 @@ static gboolean msn_ns_connected(gpointer data, gint source, b_input_condition c
 	}
 
 	if (msn_ns_write(ic, source, "VER %d %s CVR0\r\n", ++md->trId, MSNP_VER)) {
-		handler->inpa = b_input_add(handler->fd, B_EV_IO_READ, msn_ns_callback, handler);
+		if (!md->is_http) {
+			md->inpa = b_input_add(md->fd, B_EV_IO_READ, msn_ns_callback, md);
+		}
 		imcb_log(ic, "Connected to server, waiting for reply");
 	}
 
 	return FALSE;
 }
 
-void msn_ns_close(struct msn_handler_data *handler)
+void msn_ns_close(struct msn_data *md)
 {
-	if (handler->fd >= 0) {
-		closesocket(handler->fd);
-		b_event_remove(handler->inpa);
+	if (md->gw) {
+		msn_gw_free(md->gw);
+	}
+	if (md->fd >= 0) {
+		closesocket(md->fd);
+		b_event_remove(md->inpa);
 	}
 
-	handler->fd = handler->inpa = -1;
-	g_free(handler->rxq);
-	g_free(handler->cmd_text);
+	md->fd = md->inpa = -1;
+	g_free(md->rxq);
+	g_free(md->cmd_text);
 
-	handler->rxlen = 0;
-	handler->rxq = NULL;
-	handler->cmd_text = NULL;
+	md->rxlen = 0;
+	md->rxq = NULL;
+	md->cmd_text = NULL;
 }
 
 static gboolean msn_ns_callback(gpointer data, gint source, b_input_condition cond)
 {
-	struct msn_handler_data *handler = data;
-	struct im_connection *ic = handler->data;
+	struct msn_data *md = data;
+	struct im_connection *ic = md->ic;
+	char *bytes;
+	int st;
 
-	if (msn_handler(handler) == -1) {  /* Don't do this on ret == 0, it's already done then. */
+	if (md->is_http) {
+		st = msn_gw_read(md->gw, &bytes);
+	} else {
+		bytes = g_malloc(1024);
+		st = read(md->fd, bytes, 1024);
+	}
+
+	if (st <= 0) {
 		imcb_error(ic, "Error while reading from server");
 		imc_logout(ic, TRUE);
-
+		g_free(bytes);
 		return FALSE;
-	} else {
-		return TRUE;
 	}
+
+	msn_queue_feed(md, bytes, st);
+
+	g_free(bytes);
+
+	return msn_handler(md);
 }
 
-static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_parts)
+int msn_ns_command(struct msn_data *md, char **cmd, int num_parts)
 {
-	struct im_connection *ic = handler->data;
-	struct msn_data *md = ic->proto_data;
+	struct im_connection *ic = md->ic;
 
 	if (num_parts == 0) {
 		/* Hrrm... Empty command...? Ignore? */
@@ -184,18 +207,18 @@ static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_
 			return(0);
 		}
 
-		return(msn_ns_write(ic, handler->fd, "CVR %d 0x0409 mac 10.2.0 ppc macmsgs 3.5.1 macmsgs %s\r\n",
+		return(msn_ns_write(ic, md->fd, "CVR %d 0x0409 mac 10.2.0 ppc macmsgs 3.5.1 macmsgs %s VmVyc2lvbjogMQ0KWGZyQ291bnQ6IDINClhmclNlbnRVVENUaW1lOiA2MzU2MTQ3OTU5NzgzOTAwMDANCklzR2VvWGZyOiB0cnVlDQo=\r\n",
 		                    ++md->trId, ic->acc->user));
 	} else if (strcmp(cmd[0], "CVR") == 0) {
 		/* We don't give a damn about the information we just received */
-		return msn_ns_write(ic, handler->fd, "USR %d SSO I %s\r\n", ++md->trId, ic->acc->user);
+		return msn_ns_write(ic, md->fd, "USR %d SSO I %s\r\n", ++md->trId, ic->acc->user);
 	} else if (strcmp(cmd[0], "XFR") == 0) {
 		char *server;
 		int port;
 
 		if (num_parts >= 6 && strcmp(cmd[2], "NS") == 0) {
-			b_event_remove(handler->inpa);
-			handler->inpa = -1;
+			b_event_remove(md->inpa);
+			md->inpa = -1;
 
 			server = strchr(cmd[3], ':');
 			if (!server) {
@@ -208,54 +231,7 @@ static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_
 			server = cmd[3];
 
 			imcb_log(ic, "Transferring to other server");
-			return msn_ns_connect(ic, handler, server, port);
-		} else if (num_parts >= 6 && strcmp(cmd[2], "SB") == 0) {
-			struct msn_switchboard *sb;
-
-			server = strchr(cmd[3], ':');
-			if (!server) {
-				imcb_error(ic, "Syntax error");
-				imc_logout(ic, TRUE);
-				return(0);
-			}
-			*server = 0;
-			port = atoi(server + 1);
-			server = cmd[3];
-
-			if (strcmp(cmd[4], "CKI") != 0) {
-				imcb_error(ic, "Unknown authentication method for switchboard");
-				imc_logout(ic, TRUE);
-				return(0);
-			}
-
-			debug("Connecting to a new switchboard with key %s", cmd[5]);
-
-			if ((sb = msn_sb_create(ic, server, port, cmd[5], MSN_SB_NEW)) == NULL) {
-				/* Although this isn't strictly fatal for the NS connection, it's
-				   definitely something serious (we ran out of file descriptors?). */
-				imcb_error(ic, "Could not create new switchboard");
-				imc_logout(ic, TRUE);
-				return(0);
-			}
-
-			if (md->msgq) {
-				struct msn_message *m = md->msgq->data;
-				GSList *l;
-
-				sb->who = g_strdup(m->who);
-
-				/* Move all the messages to the first user in the message
-				   queue to the switchboard message queue. */
-				l = md->msgq;
-				while (l) {
-					m = l->data;
-					l = l->next;
-					if (strcmp(m->who, sb->who) == 0) {
-						sb->msgq = g_slist_append(sb->msgq, m);
-						md->msgq = g_slist_remove(md->msgq, m);
-					}
-				}
-			}
+			return msn_ns_connect(ic, server, port);
 		} else {
 			imcb_error(ic, "Syntax error");
 			imc_logout(ic, TRUE);
@@ -289,25 +265,20 @@ static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_
 			return(0);
 		}
 
-		handler->msglen = atoi(cmd[3]);
+		md->msglen = atoi(cmd[3]);
 
-		if (handler->msglen <= 0) {
+		if (md->msglen <= 0) {
 			imcb_error(ic, "Syntax error");
 			imc_logout(ic, TRUE);
 			return(0);
 		}
-	} else if (strcmp(cmd[0], "BLP") == 0) {
-		msn_ns_send_adl_start(ic);
-		return msn_ns_finish_login(ic);
 	} else if (strcmp(cmd[0], "ADL") == 0) {
 		if (num_parts >= 3 && strcmp(cmd[2], "OK") == 0) {
 			msn_ns_send_adl(ic);
 			return msn_ns_finish_login(ic);
 		} else if (num_parts >= 3) {
-			handler->msglen = atoi(cmd[2]);
+			md->msglen = atoi(cmd[2]);
 		}
-	} else if (strcmp(cmd[0], "PRP") == 0) {
-		imcb_connected(ic);
 	} else if (strcmp(cmd[0], "CHL") == 0) {
 		char *resp;
 		int st;
@@ -325,180 +296,27 @@ static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_
 		                   strlen(resp), resp);
 		g_free(resp);
 		return st;
-	} else if (strcmp(cmd[0], "ILN") == 0 || strcmp(cmd[0], "NLN") == 0) {
-		const struct msn_away_state *st;
-		const char *handle;
-		int cap = 0;
-
-		if (num_parts < 6) {
-			imcb_error(ic, "Syntax error");
-			imc_logout(ic, TRUE);
-			return(0);
-		}
-		/* ILN and NLN are more or less the same, except ILN has a trId
-		   at the start, and NLN has a capability field at the end.
-		   Does ILN still exist BTW? */
-		if (cmd[0][1] == 'I') {
-			cmd++;
-		} else {
-			cap = atoi(cmd[4]);
-		}
-
-		handle = msn_normalize_handle(cmd[2]);
-		if (strcmp(handle, ic->acc->user) == 0) {
-			return 1; /* That's me! */
-
-		}
-		http_decode(cmd[3]);
-		imcb_rename_buddy(ic, handle, cmd[3]);
-
-		st = msn_away_state_by_code(cmd[1]);
-		if (!st) {
-			/* FIXME: Warn/Bomb about unknown away state? */
-			st = msn_away_state_list + 1;
-		}
-
-		imcb_buddy_status(ic, handle, OPT_LOGGED_IN |
-		                  (st != msn_away_state_list ? OPT_AWAY : 0) |
-		                  (cap & 1 ? OPT_MOBILE : 0),
-		                  st->name, NULL);
-
-		msn_sb_stop_keepalives(msn_sb_by_handle(ic, handle));
-	} else if (strcmp(cmd[0], "FLN") == 0) {
-		const char *handle;
-
-		if (cmd[1] == NULL) {
-			return 1;
-		}
-
-		handle = msn_normalize_handle(cmd[1]);
-		imcb_buddy_status(ic, handle, 0, NULL, NULL);
-		msn_sb_start_keepalives(msn_sb_by_handle(ic, handle), TRUE);
-	} else if (strcmp(cmd[0], "RNG") == 0) {
-		struct msn_switchboard *sb;
-		char *server;
-		int session, port;
-
-		if (num_parts < 7) {
-			imcb_error(ic, "Syntax error");
-			imc_logout(ic, TRUE);
-			return(0);
-		}
-
-		session = atoi(cmd[1]);
-
-		server = strchr(cmd[2], ':');
-		if (!server) {
-			imcb_error(ic, "Syntax error");
-			imc_logout(ic, TRUE);
-			return(0);
-		}
-		*server = 0;
-		port = atoi(server + 1);
-		server = cmd[2];
-
-		if (strcmp(cmd[3], "CKI") != 0) {
-			imcb_error(ic, "Unknown authentication method for switchboard");
-			imc_logout(ic, TRUE);
-			return(0);
-		}
-
-		debug("Got a call from %s (session %d). Key = %s", cmd[5], session, cmd[4]);
-
-		if ((sb = msn_sb_create(ic, server, port, cmd[4], session)) == NULL) {
-			/* Although this isn't strictly fatal for the NS connection, it's
-			   definitely something serious (we ran out of file descriptors?). */
-			imcb_error(ic, "Could not create new switchboard");
-			imc_logout(ic, TRUE);
-			return(0);
-		} else {
-			sb->who = g_strdup(msn_normalize_handle(cmd[5]));
-		}
+	} else if (strcmp(cmd[0], "QRY") == 0) {
+		/* CONGRATULATIONS */
 	} else if (strcmp(cmd[0], "OUT") == 0) {
-		int allow_reconnect = TRUE;
-
-		if (cmd[1] && strcmp(cmd[1], "OTH") == 0) {
-			imcb_error(ic, "Someone else logged in with your account");
-			allow_reconnect = FALSE;
-		} else if (cmd[1] && strcmp(cmd[1], "SSD") == 0) {
-			imcb_error(ic, "Terminating session because of server shutdown");
-		} else {
-			imcb_error(ic, "Session terminated by remote server (%s)",
-			           cmd[1] ? cmd[1] : "reason unknown)");
-		}
-
-		imc_logout(ic, allow_reconnect);
+		imcb_error(ic, "Session terminated by remote server (%s)", cmd[1] ? cmd[1] : "reason unknown");
+		imc_logout(ic, TRUE);
 		return(0);
-	} else if (strcmp(cmd[0], "IPG") == 0) {
-		imcb_error(ic, "Received IPG command, we don't handle them yet.");
-
-		handler->msglen = atoi(cmd[1]);
-
-		if (handler->msglen <= 0) {
-			imcb_error(ic, "Syntax error");
-			imc_logout(ic, TRUE);
-			return(0);
-		}
-	}
-#if 0
-	else if (strcmp(cmd[0], "ADG") == 0) {
-		char *group = g_strdup(cmd[3]);
-		int groupnum, i;
-		GSList *l, *next;
-
-		http_decode(group);
-		if (sscanf(cmd[4], "%d", &groupnum) == 1) {
-			if (groupnum >= md->groupcount) {
-				md->grouplist = g_renew(char *, md->grouplist, groupnum + 1);
-				for (i = md->groupcount; i <= groupnum; i++) {
-					md->grouplist[i] = NULL;
-				}
-				md->groupcount = groupnum + 1;
-			}
-			g_free(md->grouplist[groupnum]);
-			md->grouplist[groupnum] = group;
-		} else {
-			/* Shouldn't happen, but if it does, give up on the group. */
-			g_free(group);
-			imcb_error(ic, "Syntax error");
-			imc_logout(ic, TRUE);
-			return 0;
-		}
-
-		for (l = md->grpq; l; l = next) {
-			struct msn_groupadd *ga = l->data;
-			next = l->next;
-			if (g_strcasecmp(ga->group, group) == 0) {
-				if (!msn_buddy_list_add(ic, "FL", ga->who, ga->who, group)) {
-					return 0;
-				}
-
-				g_free(ga->group);
-				g_free(ga->who);
-				g_free(ga);
-				md->grpq = g_slist_remove(md->grpq, ga);
-			}
-		}
-	}
-#endif
-	else if (strcmp(cmd[0], "GCF") == 0) {
+	} else if (strcmp(cmd[0], "GCF") == 0) {
 		/* Coming up is cmd[2] bytes of stuff we're supposed to
 		   censore. Meh. */
-		handler->msglen = atoi(cmd[2]);
-	} else if (strcmp(cmd[0], "UBX") == 0) {
-		/* Status message. */
+		md->msglen = atoi(cmd[2]);
+	} else if ((strcmp(cmd[0], "NFY") == 0) || (strcmp(cmd[0], "SDG") == 0)) {
 		if (num_parts >= 3) {
-			handler->msglen = atoi(cmd[2]);
+			md->msglen = atoi(cmd[2]);
+		}
+	} else if (strcmp(cmd[0], "PUT") == 0) {
+		if (num_parts >= 4) {
+			md->msglen = atoi(cmd[3]);
 		}
 	} else if (strcmp(cmd[0], "NOT") == 0) {
-		/* Some kind of notification, poorly documented but
-		   apparently used to announce address book changes. */
 		if (num_parts >= 2) {
-			handler->msglen = atoi(cmd[1]);
-		}
-	} else if (strcmp(cmd[0], "UBM") == 0) {
-		if (num_parts >= 7) {
-			handler->msglen = atoi(cmd[6]);
+			md->msglen = atoi(cmd[1]);
 		}
 	} else if (strcmp(cmd[0], "QNG") == 0) {
 		ic->flags |= OPT_PONGED;
@@ -515,18 +333,18 @@ static int msn_ns_command(struct msn_handler_data *handler, char **cmd, int num_
 
 		/* Oh yes, errors can have payloads too now. Discard them for now. */
 		if (num_parts >= 3) {
-			handler->msglen = atoi(cmd[2]);
+			md->msglen = atoi(cmd[2]);
 		}
 	} else {
-		/* debug( "Received unknown command from main server: %s", cmd[0] ); */
+		imcb_error(ic, "Received unknown command from main server: %s", cmd[0]);
 	}
 
 	return(1);
 }
 
-static int msn_ns_message(struct msn_handler_data *handler, char *msg, int msglen, char **cmd, int num_parts)
+int msn_ns_message(struct msn_data *md, char *msg, int msglen, char **cmd, int num_parts)
 {
-	struct im_connection *ic = handler->data;
+	struct im_connection *ic = md->ic;
 	char *body;
 	int blen = 0;
 
@@ -575,9 +393,9 @@ static int msn_ns_message(struct msn_handler_data *handler, char *msg, int msgle
 					char *folders = get_rfc822_header(body, "Folders-Unread:", blen);
 
 					if (inbox && folders) {
-						imcb_log(ic,
-						         "INBOX contains %s new messages, plus %s messages in other folders.", inbox,
-						         folders);
+						imcb_notify_email(ic,
+						        "INBOX contains %s new messages, plus %s messages in other folders.", inbox,
+						        folders);
 					}
 
 					g_free(inbox);
@@ -589,84 +407,18 @@ static int msn_ns_message(struct msn_handler_data *handler, char *msg, int msgle
 					char *fromname = get_rfc822_header(body, "From:", blen);
 
 					if (from && fromname) {
-						imcb_log(ic, "Received an e-mail message from %s <%s>.", fromname,
-						         from);
+						imcb_notify_email(ic, "Received an e-mail message from %s <%s>.", fromname, from);
 					}
 
 					g_free(from);
 					g_free(fromname);
 				}
 			} else if (g_strncasecmp(ct, "text/x-msmsgsactivemailnotification", 35) == 0) {
-			} else if (g_strncasecmp(ct, "text/x-msmsgsinitialmdatanotification", 37) == 0 ||
-			           g_strncasecmp(ct, "text/x-msmsgsoimnotification", 28) == 0) {
-				/* We received an offline message. Or at least notification
-				   that there is one waiting for us. Fetching the message(s)
-				   and purging them from the server is a lot of SOAPy work
-				   not worth doing IMHO. Also I thought it was possible to
-				   have the notification server send them directly, I was
-				   pretty sure I saw Pidgin do it..
-
-				   At least give a notification for now, seems like a
-				   reasonable thing to do. Only problem is, they'll keep
-				   coming back at login time until you read them using a
-				   different client. :-( */
-
-				char *xml = get_rfc822_header(body, "Mail-Data:", blen);
-				struct xt_node *md, *m;
-
-				if (!xml) {
-					return 1;
-				}
-				md = xt_from_string(xml, 0);
-				if (!md) {
-					return 1;
-				}
-
-				for (m = md->children; (m = xt_find_node(m, "M")); m = m->next) {
-					struct xt_node *e = xt_find_node(m->children, "E");
-					struct xt_node *rt = xt_find_node(m->children, "RT");
-					struct tm tp;
-					time_t msgtime = 0;
-
-					if (!e || !e->text) {
-						continue;
-					}
-
-					memset(&tp, 0, sizeof(tp));
-					if (rt && rt->text &&
-					    sscanf(rt->text, "%4d-%2d-%2dT%2d:%2d:%2d.",
-					           &tp.tm_year, &tp.tm_mon, &tp.tm_mday,
-					           &tp.tm_hour, &tp.tm_min, &tp.tm_sec) == 6) {
-						tp.tm_year -= 1900;
-						tp.tm_mon--;
-						msgtime = mktime_utc(&tp);
-
-					}
-					imcb_buddy_msg(ic, e->text,
-					               "<< \002BitlBee\002 - Received offline message. BitlBee can't show these. >>", 0,
-					               msgtime);
-				}
-
-				g_free(xml);
-				xt_free_node(md);
-			} else {
-				debug("Can't handle %s packet from notification server", ct);
+				/* Notification that a message has been read... Ignore it */
 			}
 
 			g_free(ct);
 		}
-	} else if (strcmp(cmd[0], "UBX") == 0) {
-		struct xt_node *ubx, *psm;
-		char *psm_text = NULL;
-
-		ubx = xt_from_string(msg, msglen);
-		if (ubx && strcmp(ubx->name, "Data") == 0 &&
-		    (psm = xt_find_node(ubx->children, "PSM"))) {
-			psm_text = psm->text;
-		}
-
-		imcb_buddy_status_msg(ic, msn_normalize_handle(cmd[1]), psm_text);
-		xt_free_node(ubx);
 	} else if (strcmp(cmd[0], "ADL") == 0) {
 		struct xt_node *adl, *d, *c;
 
@@ -715,37 +467,118 @@ static int msn_ns_message(struct msn_handler_data *handler, char *msg, int msgle
 				}
 			}
 		}
-	} else if (strcmp(cmd[0], "UBM") == 0) {
-		/* This one will give us msgs from federated networks. Technically
-		   it should also get us offline messages, but I don't know how
-		   I can signal MSN servers to use it. */
-		char *ct, *handle;
-
-		if (strcmp(cmd[1], ic->acc->user) == 0) {
-			/* With MPOP, you'll get copies of your own msgs from other
-			   sessions. Discard those at least for now. */
-			return 1;
-		}
-
-		ct = get_rfc822_header(msg, "Content-Type", msglen);
-		if (strncmp(ct, "text/plain", 10) != 0) {
-			/* Typing notification or something? */
-			g_free(ct);
-			return 1;
-		}
-		if (strcmp(cmd[2], "1") != 0) {
-			handle = g_strdup_printf("%s:%s", cmd[2], cmd[1]);
-		} else {
-			handle = g_strdup(cmd[1]);
-		}
-
-		imcb_buddy_msg(ic, handle, body, 0, 0);
-		g_free(handle);
+	} else if ((strcmp(cmd[0], "SDG") == 0) || (strcmp(cmd[0], "NFY") == 0)) {
+		msn_ns_structured_message(md, msg, msglen, cmd);
 	}
 
 	return 1;
 }
 
+static void msn_ns_structured_message(struct msn_data *md, char *msg, int msglen, char **cmd)
+{
+	char **parts = NULL;
+	char *semicolon = NULL;
+	char *action = NULL;
+	char *from = NULL;
+	char *who = NULL;
+
+	parts = g_strsplit(msg, "\r\n\r\n", 4);
+
+	if (!(from = get_rfc822_header(parts[0], "From", 0))) {
+		goto cleanup;
+	}
+
+	/* either the semicolon or the end of the string */
+	semicolon = strchr(from, ';') ? : (from + strlen(from));
+
+	who = g_strndup(from + 2, semicolon - from - 2);
+
+	if ((strcmp(cmd[0], "SDG") == 0) && (action = get_rfc822_header(parts[2], "Message-Type", 0))) {
+		msn_ns_sdg(md, who, parts, action);
+
+	} else if ((strcmp(cmd[0], "NFY") == 0) && (action = get_rfc822_header(parts[2], "Uri", 0))) {
+		gboolean is_put = (strcmp(cmd[1], "PUT") == 0);
+		msn_ns_nfy(md, who, parts, action, is_put);
+	}
+
+cleanup:
+	g_strfreev(parts);
+	g_free(action);
+	g_free(from);
+	g_free(who);
+}
+
+static void msn_ns_sdg(struct msn_data *md, char *who, char **parts, char *action)
+{
+	struct im_connection *ic = md->ic;
+
+	if (strcmp(action, "Control/Typing") == 0) {
+		imcb_buddy_typing(ic, who, OPT_TYPING);
+	} else if (strcmp(action, "Text") == 0) {
+		imcb_buddy_msg(ic, who, parts[3], 0, 0);
+	}
+}
+
+static void msn_ns_nfy(struct msn_data *md, char *who, char **parts, char *action, gboolean is_put)
+{
+	struct im_connection *ic = md->ic;
+	struct xt_node *body = NULL;
+	struct xt_node *s = NULL;
+	const char *state = NULL;
+	char *nick = NULL;
+	char *psm = NULL;
+	int flags = OPT_LOGGED_IN;
+
+	if (strcmp(action, "/user") != 0) {
+		return;
+	}
+
+	if (!(body = xt_from_string(parts[3], 0))) {
+		goto cleanup;
+	}
+
+	s = body->children;
+	while ((s = xt_find_node(s, "s"))) {
+		struct xt_node *s2;
+		char *n = xt_find_attr(s, "n");  /* service name: IM, PE, etc */
+
+		if (strcmp(n, "IM") == 0) {
+			/* IM has basic presence information */
+			if (!is_put) {
+				/* NFY DEL with a <s> usually means log out from the last endpoint */
+				flags &= ~OPT_LOGGED_IN;
+				break;
+			}
+
+			s2 = xt_find_node(s->children, "Status");
+			if (s2 && s2->text_len) {
+				const struct msn_away_state *msn_state = msn_away_state_by_code(s2->text);
+				state = msn_state->name;
+				if (msn_state != msn_away_state_list) {
+					flags |= OPT_AWAY;
+				}
+			}
+		} else if (strcmp(n, "PE") == 0) {
+			if ((s2 = xt_find_node(s->children, "PSM")) && s2->text_len) {
+				psm = s2->text;
+			}
+			if ((s2 = xt_find_node(s->children, "FriendlyName")) && s2->text_len) {
+				nick = s2->text;
+			}
+		}
+		s = s->next;
+	}
+
+	imcb_buddy_status(ic, who, flags, state, psm);
+
+	if (nick) {
+		imcb_rename_buddy(ic, who, nick);
+	}
+
+cleanup:
+	xt_free_node(body);
+}
+
 void msn_auth_got_passport_token(struct im_connection *ic, const char *token, const char *error)
 {
 	struct msn_data *md;
@@ -767,20 +600,18 @@ void msn_auth_got_passport_token(struct im_connection *ic, const char *token, co
 
 void msn_auth_got_contact_list(struct im_connection *ic)
 {
-	struct msn_data *md;
-
 	/* Dead connection? */
 	if (g_slist_find(msn_connections, ic) == NULL) {
 		return;
 	}
 
-	md = ic->proto_data;
-	msn_ns_write(ic, -1, "BLP %d %s\r\n", ++md->trId, "BL");
+	msn_ns_send_adl_start(ic);
+	msn_ns_finish_login(ic);
 }
 
 static gboolean msn_ns_send_adl_1(gpointer key, gpointer value, gpointer data)
 {
-	struct xt_node *adl = data, *d, *c;
+	struct xt_node *adl = data, *d, *c, *s;
 	struct bee_user *bu = value;
 	struct msn_buddy_data *bd = bu->data;
 	struct msn_data *md = bu->ic->proto_data;
@@ -788,7 +619,7 @@ static gboolean msn_ns_send_adl_1(gpointer key, gpointer value, gpointer data)
 	char *domain;
 	char l[4];
 
-	if ((bd->flags & 7) == 0 || (bd->flags & MSN_BUDDY_ADL_SYNCED)) {
+	if ((bd->flags & (MSN_BUDDY_FL | MSN_BUDDY_AL)) == 0 || (bd->flags & MSN_BUDDY_ADL_SYNCED)) {
 		return FALSE;
 	}
 
@@ -806,11 +637,14 @@ static gboolean msn_ns_send_adl_1(gpointer key, gpointer value, gpointer data)
 		xt_insert_child(adl, d);
 	}
 
-	g_snprintf(l, sizeof(l), "%d", bd->flags & 7);
+	g_snprintf(l, sizeof(l), "%d", bd->flags & (MSN_BUDDY_FL | MSN_BUDDY_AL));
 	c = xt_new_node("c", NULL, NULL);
 	xt_add_attr(c, "n", handle);
-	xt_add_attr(c, "l", l);
 	xt_add_attr(c, "t", "1");   /* FIXME: Network type, i.e. 32 for Y!MSG */
+	s = xt_new_node("s", NULL, NULL);
+	xt_add_attr(s, "n", "IM");
+	xt_add_attr(s, "l", l);
+	xt_insert_child(c, s);
 	xt_insert_child(d, c);
 
 	/* Do this in batches of 100. */
@@ -856,7 +690,7 @@ static void msn_ns_send_adl_start(struct im_connection *ic)
 		bee_user_t *bu = l->data;
 		struct msn_buddy_data *bd = bu->data;
 
-		if (bu->ic != ic || (bd->flags & 7) == 0) {
+		if (bu->ic != ic || (bd->flags & (MSN_BUDDY_FL | MSN_BUDDY_AL)) == 0) {
 			continue;
 		}
 
@@ -880,72 +714,31 @@ int msn_ns_finish_login(struct im_connection *ic)
 	}
 
 	if ((md->flags & MSN_DONE_ADL) && (md->flags & MSN_GOT_PROFILE)) {
-		if (md->flags & MSN_EMAIL_UNVERIFIED) {
-			imcb_connected(ic);
-		} else {
-			return msn_ns_set_display_name(ic, set_getstr(&ic->acc->set, "display_name"));
-		}
+		imcb_connected(ic);
 	}
 
 	return 1;
 }
 
-int msn_ns_sendmessage(struct im_connection *ic, bee_user_t *bu, const char *text)
+static int msn_ns_send_sdg(struct im_connection *ic, bee_user_t *bu, const char *message_type, const char *text)
 {
 	struct msn_data *md = ic->proto_data;
-	int type = 0;
-	char *buf, *handle;
+	int retval = 0;
+	char *buf;
 
-	if (strncmp(text, "\r\r\r", 3) == 0) {
-		/* Err. Shouldn't happen but I guess it can. Don't send others
-		   any of the "SHAKE THAT THING" messages. :-D */
-		return 1;
-	}
-
-	/* This might be a federated contact. Get its network number,
-	   prefixed to bu->handle with a colon. Default is 1. */
-	for (handle = bu->handle; g_ascii_isdigit(*handle); handle++) {
-		type = type * 10 + *handle - '0';
-	}
-	if (*handle == ':') {
-		handle++;
-	} else {
-		type = 1;
-	}
-
-	buf = g_strdup_printf("%s%s", MSN_MESSAGE_HEADERS, text);
-
-	if (msn_ns_write(ic, -1, "UUM %d %s %d %d %zd\r\n%s",
-	                 ++md->trId, handle, type,
-	                 1,          /* type == IM (not nudge/typing) */
-	                 strlen(buf), buf)) {
-		return 1;
-	} else {
-		return 0;
-	}
+	buf = g_strdup_printf(MSN_MESSAGE_HEADERS, bu->handle, ic->acc->user, md->uuid, message_type, strlen(text), text);
+	retval = msn_ns_write(ic, -1, "SDG %d %zd\r\n%s", ++md->trId, strlen(buf), buf);
+	g_free(buf);
+	return retval;
 }
 
-void msn_ns_oim_send_queue(struct im_connection *ic, GSList **msgq)
+int msn_ns_send_typing(struct im_connection *ic, bee_user_t *bu)
 {
-	GSList *l;
-
-	for (l = *msgq; l; l = l->next) {
-		struct msn_message *m = l->data;
-		bee_user_t *bu = bee_user_by_handle(ic->bee, ic, m->who);
-
-		if (bu) {
-			if (!msn_ns_sendmessage(ic, bu, m->text)) {
-				return;
-			}
-		}
-	}
-
-	while (*msgq != NULL) {
-		struct msn_message *m = (*msgq)->data;
-
-		*msgq = g_slist_remove(*msgq, m);
-		g_free(m->who);
-		g_free(m->text);
-		g_free(m);
-	}
+	return msn_ns_send_sdg(ic, bu, "Control/Typing", "");
 }
+
+int msn_ns_send_message(struct im_connection *ic, bee_user_t *bu, const char *text)
+{
+	return msn_ns_send_sdg(ic, bu, "Text", text);
+}
+
