@@ -1,27 +1,14 @@
 #include <aim.h>
 
-static aim_tlv_t *createtlv(void)
-{
-	aim_tlv_t *newtlv;
-
-	if (!(newtlv = (aim_tlv_t *)g_malloc(sizeof(aim_tlv_t))))
-		return NULL;
-	memset(newtlv, 0, sizeof(aim_tlv_t));
-
-	return newtlv;
-}
-
 static void freetlv(aim_tlv_t **oldtlv)
 {
-
-	if (!oldtlv || !*oldtlv)
+	if (!oldtlv || !*oldtlv) {
 		return;
-	
+	}
+
 	g_free((*oldtlv)->value);
 	g_free(*oldtlv);
 	*oldtlv = NULL;
-
-	return;
 }
 
 /**
@@ -35,7 +22,7 @@ static void freetlv(aim_tlv_t **oldtlv)
  * be called to free the dynamic substructures.
  *
  * XXX There should be a flag setable here to have the tlvlist contain
- * bstream references, so that at least the ->value portion of each 
+ * bstream references, so that at least the ->value portion of each
  * element doesn't need to be malloc/memcpy'd.  This could prove to be
  * just as effecient as the in-place TLV parsing used in a couple places
  * in libfaim.
@@ -51,34 +38,16 @@ aim_tlvlist_t *aim_readtlvchain(aim_bstream_t *bs)
 		type = aimbs_get16(bs);
 		length = aimbs_get16(bs);
 
-#if 0 /* temporarily disabled until I know if they're still doing it or not */
-		/*
-		 * Okay, so now AOL has decided that any TLV of
-		 * type 0x0013 can only be two bytes, despite
-		 * what the actual given length is.  So here 
-		 * we dump any invalid TLVs of that sort.  Hopefully
-		 * theres no special cases to this special case.
-		 *   - mid (30jun2000)
-		 */
-		if ((type == 0x0013) && (length != 0x0002))
-			length = 0x0002;
-#else
-		if (0)
-			;
-#endif
-		else {
+		cur = g_new0(aim_tlvlist_t, 1);
 
-			cur = (aim_tlvlist_t *)g_malloc(sizeof(aim_tlvlist_t));
-			memset(cur, 0, sizeof(aim_tlvlist_t));
-
-			cur->tlv = createtlv();	
-			cur->tlv->type = type;
-			if ((cur->tlv->length = length))
-			       cur->tlv->value = aimbs_getraw(bs, length);	
-
-			cur->next = list;
-			list = cur;
+		cur->tlv = g_new0(aim_tlv_t, 1);
+		cur->tlv->type = type;
+		if ((cur->tlv->length = length)) {
+			cur->tlv->value = aimbs_getraw(bs, length);
 		}
+
+		cur->next = list;
+		list = cur;
 	}
 
 	return list;
@@ -97,12 +66,13 @@ void aim_freetlvchain(aim_tlvlist_t **list)
 {
 	aim_tlvlist_t *cur;
 
-	if (!list || !*list)
+	if (!list || !*list) {
 		return;
+	}
 
 	for (cur = *list; cur; ) {
 		aim_tlvlist_t *tmp;
-		
+
 		freetlv(&cur->tlv);
 
 		tmp = cur->next;
@@ -127,11 +97,13 @@ int aim_counttlvchain(aim_tlvlist_t **list)
 	aim_tlvlist_t *cur;
 	int count;
 
-	if (!list || !*list)
+	if (!list || !*list) {
 		return 0;
+	}
 
-	for (cur = *list, count = 0; cur; cur = cur->next)
+	for (cur = *list, count = 0; cur; cur = cur->next) {
 		count++;
+	}
 
 	return count;
 }
@@ -140,7 +112,7 @@ int aim_counttlvchain(aim_tlvlist_t **list)
  * aim_sizetlvchain - Count the number of bytes in a TLV chain
  * @list: Chain to be sized
  *
- * Returns the number of bytes that would be needed to 
+ * Returns the number of bytes that would be needed to
  * write the passed TLV chain to a data buffer.
  *
  */
@@ -149,11 +121,13 @@ int aim_sizetlvchain(aim_tlvlist_t **list)
 	aim_tlvlist_t *cur;
 	int size;
 
-	if (!list || !*list)
+	if (!list || !*list) {
 		return 0;
+	}
 
-	for (cur = *list, size = 0; cur; cur = cur->next)
+	for (cur = *list, size = 0; cur; cur = cur->next) {
 		size += (4 + cur->tlv->length);
+	}
 
 	return size;
 }
@@ -173,28 +147,30 @@ int aim_addtlvtochain_raw(aim_tlvlist_t **list, const guint16 t, const guint16 l
 {
 	aim_tlvlist_t *newtlv, *cur;
 
-	if (!list)
+	if (!list) {
 		return 0;
+	}
 
-	if (!(newtlv = (aim_tlvlist_t *)g_malloc(sizeof(aim_tlvlist_t))))
+	if (!(newtlv = g_new0(aim_tlvlist_t, 1))) {
 		return 0;
-	memset(newtlv, 0x00, sizeof(aim_tlvlist_t));
+	}
 
-	if (!(newtlv->tlv = createtlv())) {
+	if (!(newtlv->tlv = g_new0(aim_tlv_t, 1))) {
 		g_free(newtlv);
 		return 0;
 	}
 	newtlv->tlv->type = t;
 	if ((newtlv->tlv->length = l)) {
-		newtlv->tlv->value = (guint8 *)g_malloc(newtlv->tlv->length);
+		newtlv->tlv->value = (guint8 *) g_malloc(newtlv->tlv->length);
 		memcpy(newtlv->tlv->value, v, newtlv->tlv->length);
 	}
 
-	if (!*list)
+	if (!*list) {
 		*list = newtlv;
-	else {
-		for(cur = *list; cur->next; cur = cur->next)
+	} else {
+		for (cur = *list; cur->next; cur = cur->next) {
 			;
+		}
 		cur->next = newtlv;
 	}
 
@@ -214,7 +190,7 @@ int aim_addtlvtochain8(aim_tlvlist_t **list, const guint16 t, const guint8 v)
 {
 	guint8 v8[1];
 
-	aimutil_put8(v8, v);
+	(void) aimutil_put8(v8, v);
 
 	return aim_addtlvtochain_raw(list, t, 1, v8);
 }
@@ -232,7 +208,7 @@ int aim_addtlvtochain16(aim_tlvlist_t **list, const guint16 t, const guint16 v)
 {
 	guint8 v16[2];
 
-	aimutil_put16(v16, v);
+	(void) aimutil_put16(v16, v);
 
 	return aim_addtlvtochain_raw(list, t, 2, v16);
 }
@@ -250,44 +226,11 @@ int aim_addtlvtochain32(aim_tlvlist_t **list, const guint16 t, const guint32 v)
 {
 	guint8 v32[4];
 
-	aimutil_put32(v32, v);
+	(void) aimutil_put32(v32, v);
 
 	return aim_addtlvtochain_raw(list, t, 4, v32);
 }
 
-/**
- * aim_addtlvtochain_availmsg - Add a ICQ availability message to a TLV chain
- * @list: Destination chain
- * @type: TLV type to add
- * @val: Value to add
- *
- * Adds a available message to a TLV chain
- *
- */
-int aim_addtlvtochain_availmsg(aim_tlvlist_t **list, const guint16 t, const char *msg)
-{
-	int ret;
-	guint16 unknown_data = 0x00;
-	guint8 add_data_len = 4;
-	guint16 msg_len = strlen(msg);
-	guint8 total_len = strlen(msg) + add_data_len;
-	guint8 *data, *cur;
-	guint8 alloc_len = msg_len + (3*sizeof(guint16)) + (2*sizeof(guint8));
-	data = cur = g_malloc(alloc_len);
-	
-	cur += aimutil_put16(cur, 2);
-	cur += aimutil_put8(cur, add_data_len);
-	cur += aimutil_put8(cur, total_len);
-	cur += aimutil_put16(cur, msg_len);
-	cur += aimutil_putstr(cur, msg, msg_len);
-	cur += aimutil_put16(cur, unknown_data);
-
-	ret = aim_addtlvtochain_raw(list, t, alloc_len, data);
-	g_free(data);
-
-	return ret;
-}
-
 /**
  * aim_addtlvtochain_caps - Add a capability block to a TLV chain
  * @list: Destination chain
@@ -300,12 +243,13 @@ int aim_addtlvtochain_availmsg(aim_tlvlist_t **list, const guint16 t, const char
  */
 int aim_addtlvtochain_caps(aim_tlvlist_t **list, const guint16 t, const guint32 caps)
 {
-	guint8 buf[16*16]; /* XXX icky fixed length buffer */
+	guint8 buf[16 * 16]; /* XXX icky fixed length buffer */
 	aim_bstream_t bs;
 
-	if (!caps)
+	if (!caps) {
 		return 0; /* nothing there anyway */
 
+	}
 	aim_bstream_init(&bs, buf, sizeof(buf));
 
 	aim_putcap(&bs, caps);
@@ -313,18 +257,6 @@ int aim_addtlvtochain_caps(aim_tlvlist_t **list, const guint16 t, const guint32
 	return aim_addtlvtochain_raw(list, t, aim_bstream_curpos(&bs), buf);
 }
 
-int aim_addtlvtochain_userinfo(aim_tlvlist_t **list, guint16 type, aim_userinfo_t *ui)
-{
-	guint8 buf[1024]; /* bleh */
-	aim_bstream_t bs;
-
-	aim_bstream_init(&bs, buf, sizeof(buf));
-
-	aim_putuserinfo(&bs, ui);
-
-	return aim_addtlvtochain_raw(list, type, aim_bstream_curpos(&bs), buf);
-}
-
 /**
  * aim_addtlvtochain_noval - Add a blank TLV to a TLV chain
  * @list: Destination chain
@@ -344,7 +276,7 @@ int aim_addtlvtochain_noval(aim_tlvlist_t **list, const guint16 t)
  * made to this.
  *
  * XXX should probably support sublists for real.
- * 
+ *
  * This is so neat.
  *
  */
@@ -356,11 +288,13 @@ int aim_addtlvtochain_frozentlvlist(aim_tlvlist_t **list, guint16 type, aim_tlvl
 
 	buflen = aim_sizetlvchain(tl);
 
-	if (buflen <= 0)
+	if (buflen <= 0) {
 		return 0;
+	}
 
-	if (!(buf = g_malloc(buflen)))
+	if (!(buf = g_malloc(buflen))) {
 		return 0;
+	}
 
 	aim_bstream_init(&bs, buf, buflen);
 
@@ -373,6 +307,33 @@ int aim_addtlvtochain_frozentlvlist(aim_tlvlist_t **list, guint16 type, aim_tlvl
 	return buflen;
 }
 
+int aim_addtlvtochain_chatroom(aim_tlvlist_t **list, guint16 type, guint16 exchange, const char *roomname,
+                               guint16 instance)
+{
+	guint8 *buf;
+	int buflen;
+	aim_bstream_t bs;
+
+	buflen = 2 + 1 + strlen(roomname) + 2;
+
+	if (!(buf = g_malloc(buflen))) {
+		return 0;
+	}
+
+	aim_bstream_init(&bs, buf, buflen);
+
+	aimbs_put16(&bs, exchange);
+	aimbs_put8(&bs, strlen(roomname));
+	aimbs_putraw(&bs, (guint8 *) roomname, strlen(roomname));
+	aimbs_put16(&bs, instance);
+
+	aim_addtlvtochain_raw(list, type, aim_bstream_curpos(&bs), buf);
+
+	g_free(buf);
+
+	return 0;
+}
+
 /**
  * aim_writetlvchain - Write a TLV chain into a data buffer.
  * @buf: Destination buffer
@@ -380,11 +341,11 @@ int aim_addtlvtochain_frozentlvlist(aim_tlvlist_t **list, guint16 type, aim_tlvl
  * @list: Source TLV chain
  *
  * Copies a TLV chain into a raw data buffer, writing only the number
- * of bytes specified. This operation does not free the chain; 
+ * of bytes specified. This operation does not free the chain;
  * aim_freetlvchain() must still be called to free up the memory used
  * by the chain structures.
  *
- * XXX clean this up, make better use of bstreams 
+ * XXX clean this up, make better use of bstreams
  */
 int aim_writetlvchain(aim_bstream_t *bs, aim_tlvlist_t **list)
 {
@@ -397,15 +358,17 @@ int aim_writetlvchain(aim_bstream_t *bs, aim_tlvlist_t **list)
 		goodbuflen += cur->tlv->length;
 	}
 
-	if (goodbuflen > aim_bstream_empty(bs))
+	if (goodbuflen > aim_bstream_empty(bs)) {
 		return 0; /* not enough buffer */
 
+	}
 	/* do the real write-out */
 	for (cur = *list; cur; cur = cur->next) {
 		aimbs_put16(bs, cur->tlv->type);
 		aimbs_put16(bs, cur->tlv->length);
-		if (cur->tlv->length)
+		if (cur->tlv->length) {
 			aimbs_putraw(bs, cur->tlv->value, cur->tlv->length);
+		}
 	}
 
 	return 1; /* XXX this is a nonsensical return */
@@ -418,7 +381,7 @@ int aim_writetlvchain(aim_bstream_t *bs, aim_tlvlist_t **list)
  * @type: Requested TLV type
  * @nth: Index of TLV of type to get
  *
- * Returns a pointer to an aim_tlv_t of the specified type; 
+ * Returns a pointer to an aim_tlv_t of the specified type;
  * %NULL on error.  The @nth parameter is specified starting at %1.
  * In most cases, there will be no more than one TLV of any type
  * in a chain.
@@ -431,10 +394,12 @@ aim_tlv_t *aim_gettlv(aim_tlvlist_t *list, const guint16 t, const int n)
 
 	for (cur = list, i = 0; cur; cur = cur->next) {
 		if (cur && cur->tlv) {
-			if (cur->tlv->type == t)
+			if (cur->tlv->type == t) {
 				i++;
-			if (i >= n)
+			}
+			if (i >= n) {
 				return cur->tlv;
+			}
 		}
 	}
 
@@ -448,7 +413,7 @@ aim_tlv_t *aim_gettlv(aim_tlvlist_t *list, const guint16 t, const int n)
  * @nth: Index of TLV to return
  *
  * Same as aim_gettlv(), except that the return value is a %NULL-
- * terminated string instead of an aim_tlv_t.  This is a 
+ * terminated string instead of an aim_tlv_t.  This is a
  * dynamic buffer and must be freed by the caller.
  *
  */
@@ -457,8 +422,9 @@ char *aim_gettlv_str(aim_tlvlist_t *list, const guint16 t, const int n)
 	aim_tlv_t *tlv;
 	char *newstr;
 
-	if (!(tlv = aim_gettlv(list, t, n)))
+	if (!(tlv = aim_gettlv(list, t, n))) {
 		return NULL;
+	}
 
 	newstr = (char *) g_malloc(tlv->length + 1);
 	memcpy(newstr, tlv->value, tlv->length);
@@ -473,16 +439,17 @@ char *aim_gettlv_str(aim_tlvlist_t *list, const guint16 t, const int n)
  * @type: TLV type to search for
  * @nth: Index of TLV to return
  *
- * Same as aim_gettlv(), except that the return value is a 
- * 8bit integer instead of an aim_tlv_t. 
+ * Same as aim_gettlv(), except that the return value is a
+ * 8bit integer instead of an aim_tlv_t.
  *
  */
 guint8 aim_gettlv8(aim_tlvlist_t *list, const guint16 t, const int n)
 {
 	aim_tlv_t *tlv;
 
-	if (!(tlv = aim_gettlv(list, t, n)))
+	if (!(tlv = aim_gettlv(list, t, n))) {
 		return 0; /* erm */
+	}
 	return aimutil_get8(tlv->value);
 }
 
@@ -492,16 +459,17 @@ guint8 aim_gettlv8(aim_tlvlist_t *list, const guint16 t, const int n)
  * @type: TLV type to search for
  * @nth: Index of TLV to return
  *
- * Same as aim_gettlv(), except that the return value is a 
- * 16bit integer instead of an aim_tlv_t. 
+ * Same as aim_gettlv(), except that the return value is a
+ * 16bit integer instead of an aim_tlv_t.
  *
  */
 guint16 aim_gettlv16(aim_tlvlist_t *list, const guint16 t, const int n)
 {
 	aim_tlv_t *tlv;
 
-	if (!(tlv = aim_gettlv(list, t, n)))
+	if (!(tlv = aim_gettlv(list, t, n))) {
 		return 0; /* erm */
+	}
 	return aimutil_get16(tlv->value);
 }
 
@@ -511,16 +479,17 @@ guint16 aim_gettlv16(aim_tlvlist_t *list, const guint16 t, const int n)
  * @type: TLV type to search for
  * @nth: Index of TLV to return
  *
- * Same as aim_gettlv(), except that the return value is a 
- * 32bit integer instead of an aim_tlv_t. 
+ * Same as aim_gettlv(), except that the return value is a
+ * 32bit integer instead of an aim_tlv_t.
  *
  */
 guint32 aim_gettlv32(aim_tlvlist_t *list, const guint16 t, const int n)
 {
 	aim_tlv_t *tlv;
 
-	if (!(tlv = aim_gettlv(list, t, n)))
+	if (!(tlv = aim_gettlv(list, t, n))) {
 		return 0; /* erm */
+	}
 	return aimutil_get32(tlv->value);
 }
 
@@ -597,9 +566,10 @@ int aim_puttlv_raw(guint8 *buf, const guint16 t, const guint16 l, const guint8 *
 	int i;
 
 	i = aimutil_put16(buf, t);
-	i += aimutil_put16(buf+i, l);
-	if (l)
-		memcpy(buf+i, v, l);
+	i += aimutil_put16(buf + i, l);
+	if (l) {
+		memcpy(buf + i, v, l);
+	}
 	i += l;
 
 	return i;
